@@ -1,5 +1,5 @@
 plotHCA <-
-function(spectra, hclst, sub.title, use.sym, ...) {
+function(spectra, hclst, sub.title, use.sym, leg.loc, ...) {
 
 # Function to plot HCA results, basically a wrapper to existing methods
 # Part of the ChemoSpec package
@@ -11,6 +11,8 @@ function(spectra, hclst, sub.title, use.sym, ...) {
 
 	plot(cluster, sub = sub.title, horiz = FALSE, ...)
 	
+	if (leg.loc == "none") return(cluster)
+	
 	gr <- sumGroups(spectra)
 	leg.txt <- gr$group
 	leg.col <- gr$color
@@ -19,8 +21,8 @@ function(spectra, hclst, sub.title, use.sym, ...) {
 	leg.txt <- c("Key", leg.txt)
 	leg.col <- c("black", leg.col)
 	leg.sym <- c("", leg.sym)
-	if (!use.sym) legend("topright", leg.txt, text.col = leg.col, bty = "n")
-	if (use.sym) legend("topright", leg.txt, text.col = "black", pch = leg.sym, bty = "n")
+	if (!use.sym) legend(leg.loc, leg.txt, text.col = leg.col, bty = "n")
+	if (use.sym) legend(leg.loc, leg.txt, text.col = "black", pch = leg.sym, bty = "n")
 	return(cluster)
 	}
 
